@@ -607,58 +607,79 @@ def test_mncontour(grad, cl):
 
 @pytest.mark.parametrize("grad", (None, func0_grad))
 def test_contour(grad):
-    # FIXME: check the result
     m = Minuit(func0, grad=grad, x=1.0, y=2.0)
     m.migrad()
-    m.contour("x", "y")
+    x, y, v = m.contour("x", "y")
+    X, Y = np.meshgrid(x, y)
+    assert_allclose(func0(X, Y), v.T)
 
 
 @pytest.mark.parametrize("grad", (None, func0_grad))
 def test_profile(grad):
-    # FIXME: check the result
     m = Minuit(func0, grad=grad, x=1.0, y=2.0)
     m.migrad()
-    m.profile("y")
+
+    y, v = m.profile("y", subtract_min=False)
+    assert_allclose(func0(m.values[0], y), v)
+
+    v2 = m.profile("y", subtract_min=True)[1]
+    assert np.min(v2) == 0
+    assert_allclose(v - np.min(v), v2)
 
 
 @pytest.mark.parametrize("grad", (None, func0_grad))
 def test_mnprofile(grad):
-    # FIXME: check the result
     m = Minuit(func0, grad=grad, x=1.0, y=2.0)
     m.migrad()
-    if grad is None:
-        m.mnprofile("y", subtract_min=True)
+
     with pytest.raises(ValueError):
         m.mnprofile("foo")
 
+    y, v, _ = m.mnprofile("y", size=10, subtract_min=False)
+    m2 = Minuit(func0, grad=grad, x=1.0, y=2.0)
+    m2.fixed[1] = True
+    v2 = []
+    for yi in y:
+        m2.values = (m.values[0], yi)
+        m2.migrad()
+        v2.append(m2.fval)
 
-def test_mnprofile_subtract():
-    m = Minuit(func0, x=1.0, y=2.0)
-    m.migrad()
-    m.mnprofile("y", subtract_min=True)
+    assert_allclose(v, v2)
 
-
-def test_profile_subtract():
-    m = Minuit(func0, x=1.0, y=2.0)
-    m.migrad()
-    m.profile("y", subtract_min=True)
+    y, v3, _ = m.mnprofile("y", size=10, subtract_min=True)
+    assert np.min(v3) == 0
+    assert_allclose(v - np.min(v), v3)
 
 
 def test_contour_subtract():
     m = Minuit(func0, x=1.0, y=2.0)
     m.migrad()
-    m.contour("x", "y", subtract_min=True)
+    v = m.contour("x", "y", subtract_min=False)[2]
+    v2 = m.contour("x", "y", subtract_min=True)[2]
+    assert np.min(v2) == 0
+    assert_allclose(v - np.min(v), v2)
 
 
 def test_mncontour_no_fmin():
-    m = Minuit(lambda x, y: 0, x=0, y=0)
-    m.errordef = 1
-    with pytest.raises(ValueError):
-        m.mncontour("x", "y")
+    m = Minuit(func0, x=0, y=0)
+
+    with pytest.raises(RuntimeError):
+        m.mncontour("x", "y")  # fails, because this is not a minimum
+
+    # succeeds
+    m.values = (2, 5)
+    c = m.mncontour("x", "y", size=10)
+
+    # compute reference to compare with
+    m2 = Minuit(func0, x=0, y=0)
+    m2.migrad()
+    c2 = m.mncontour("x", "y", size=10)
+
+    assert_allclose(c, c2)
 
 
 def test_mncontour_with_fixed_var():
-    m = Minuit(lambda x, y: 0, x=0, y=0)
+    m = Minuit(func0, x=0, y=0)
     m.errordef = 1
     m.fixed["x"] = True
     m.migrad()
@@ -1174,21 +1195,6 @@ def test_bad_functions_np(func, expected):
     assert str(expected) in str(excinfo.value)
 
 
-def test_issue_424():
-    def lsq(x, y, z):
-        return (x - 1) ** 2 + (y - 4) ** 2 / 2 + (z - 9) ** 2 / 3
-
-    m = Minuit(lsq, x=0.0, y=0.0, z=0.0)
-    m.errordef = 1
-    m.migrad()
-
-    m.fixed["x"] = True
-    m.errors["x"] = 2
-    m.hesse()
-    assert m.fixed["x"] is True
-    assert m.errors["x"] == 2
-
-
 @pytest.mark.parametrize("sign", (-1, 1))
 def test_parameter_at_limit(sign):
     m = Minuit(lambda x: (x - sign * 1.2) ** 2, x=0)
@@ -1341,13 +1347,6 @@ def test_bad_tolerance():
         m.tol = -1
 
 
-def test_issue_544():
-    m = Minuit(func0, x=0, y=0)
-    m.fixed = True
-    with pytest.warns(IMinuitWarning):
-        m.hesse()  # this used to cause a segfault
-
-
 def test_cfunc():
     nb = pytest.importorskip("numba")
 
@@ -1495,46 +1494,9 @@ def test_missing_ndata():
     assert_equal(m.ndof, np.nan)
 
 
-def test_issue_648():
-    class F:
-        errordef = 1
-        first = True
-
-        def __call__(self, a, b):
-            if self.first:
-                assert a == 1.0 and b == 2.0
-                self.first = False
-            return a ** 2 + b ** 2
-
-    m = Minuit(F(), a=1, b=2)
-    m.fixed["a"] = False  # this used to change a to b
-    m.migrad()
-
-
 def test_call_limit_reached_in_hesse():
     m = Minuit(lambda x: ((x - 1.2) ** 4).sum(), np.ones(10) * 10)
     m.errordef = 1
     m.migrad(ncall=200)
     assert m.fmin.has_reached_call_limit
     assert m.fmin.nfcn < 205
-
-
-def test_issue_643():
-    def fcn(x, y, z):
-        return (x - 2) ** 2 + (y - 3) ** 2 + (z - 4) ** 2
-
-    fcn.errordef = Minuit.LEAST_SQUARES
-
-    m = Minuit(fcn, x=2, y=3, z=4)
-    m.migrad()
-
-    m2 = Minuit(fcn, x=m.values["x"], y=m.values["y"], z=m.values["z"])
-    # used to call MnHesse when it was not needed and quickly exhaust call limit
-    for i in range(10):
-        m2.minos()
-
-    m2.reset()
-    # used to exhaust call limit, because calls to MnHesse did not reset call count
-    for i in range(10):
-        m2.values = m.values
-        m2.minos()
